( cd usr/lib ; rm -rf libgnome-mag.so.2 )
( cd usr/lib ; ln -sf libgnome-mag.so.2.0.1 libgnome-mag.so.2 )
( cd usr/lib ; rm -rf libgnome-mag.so )
( cd usr/lib ; ln -sf libgnome-mag.so.2.0.1 libgnome-mag.so )
